package javax.swing;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleStateSet;
import javax.accessibility.AccessibleValue;
import javax.swing.event.ChangeEvent;
import java.io.Serializable;
import javax.accessibility.AccessibleContext;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.event.AdjustmentEvent;
import java.awt.event.AdjustmentListener;
import javax.accessibility.AccessibleState;
import javax.swing.plaf.ScrollBarUI;
import javax.swing.event.ChangeListener;
import javax.accessibility.Accessible;
import java.awt.Adjustable;

public class JScrollBar extends JComponent implements Adjustable, Accessible
{
    private static final String uiClassID = "ScrollBarUI";
    private ChangeListener fwdAdjustmentEvents;
    protected BoundedRangeModel model;
    protected int orientation;
    protected int unitIncrement;
    protected int blockIncrement;
    
    private void checkOrientation(int n) {
        switch (n) {
            case 0:
            case 1: {
                return;
            }
            default: {
                throw new IllegalArgumentException("orientation must be one of: VERTICAL, HORIZONTAL");
            }
        }
    }
    
    public JScrollBar(int orientation, int n, int n2, int n3, int n4) {
        this.fwdAdjustmentEvents = new JScrollBar.ModelListener();
        this.checkOrientation(orientation);
        this.unitIncrement = 1;
        this.blockIncrement = ((n2 == 0) ? 1 : n2);
        this.orientation = orientation;
        (this.model = new DefaultBoundedRangeModel(n, n2, n3, n4)).addChangeListener(this.fwdAdjustmentEvents);
        this.setRequestFocusEnabled(false);
        this.updateUI();
    }
    
    public JScrollBar(int n) {
        this(n, 0, 10, 0, 100);
    }
    
    public JScrollBar() {
        this(1);
    }
    
    public void setUI(ScrollBarUI ui) {
        super.setUI(ui);
    }
    
    public ScrollBarUI getUI() {
        return (ScrollBarUI)this.ui;
    }
    
    @Override
    public void updateUI() {
        this.setUI((ScrollBarUI)UIManager.getUI(this));
    }
    
    @Override
    public String getUIClassID() {
        return "ScrollBarUI";
    }
    
    @Override
    public int getOrientation() {
        return this.orientation;
    }
    
    public void setOrientation(int orientation) {
        this.checkOrientation(orientation);
        int orientation2 = this.orientation;
        this.firePropertyChange("orientation", orientation2, this.orientation = orientation);
        if (orientation2 != orientation && this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleState", (orientation2 == 1) ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL, (orientation == 1) ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL);
        }
        if (orientation != orientation2) {
            this.revalidate();
        }
    }
    
    public BoundedRangeModel getModel() {
        return this.model;
    }
    
    public void setModel(BoundedRangeModel model) {
        Integer value = null;
        BoundedRangeModel model2 = this.model;
        if (this.model != null) {
            this.model.removeChangeListener(this.fwdAdjustmentEvents);
            value = Integer.valueOf(this.model.getValue());
        }
        this.model = model;
        if (this.model != null) {
            this.model.addChangeListener(this.fwdAdjustmentEvents);
        }
        this.firePropertyChange("model", model2, this.model);
        if (this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleValue", value, new Integer(this.model.getValue()));
        }
    }
    
    public int getUnitIncrement(int n) {
        return this.unitIncrement;
    }
    
    @Override
    public void setUnitIncrement(int unitIncrement) {
        this.firePropertyChange("unitIncrement", this.unitIncrement, this.unitIncrement = unitIncrement);
    }
    
    public int getBlockIncrement(int n) {
        return this.blockIncrement;
    }
    
    @Override
    public void setBlockIncrement(int blockIncrement) {
        this.firePropertyChange("blockIncrement", this.blockIncrement, this.blockIncrement = blockIncrement);
    }
    
    @Override
    public int getUnitIncrement() {
        return this.unitIncrement;
    }
    
    @Override
    public int getBlockIncrement() {
        return this.blockIncrement;
    }
    
    @Override
    public int getValue() {
        return this.getModel().getValue();
    }
    
    @Override
    public void setValue(int value) {
        BoundedRangeModel model = this.getModel();
        int value2 = model.getValue();
        model.setValue(value);
        if (this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleValue", Integer.valueOf(value2), Integer.valueOf(model.getValue()));
        }
    }
    
    @Override
    public int getVisibleAmount() {
        return this.getModel().getExtent();
    }
    
    @Override
    public void setVisibleAmount(int extent) {
        this.getModel().setExtent(extent);
    }
    
    @Override
    public int getMinimum() {
        return this.getModel().getMinimum();
    }
    
    @Override
    public void setMinimum(int minimum) {
        this.getModel().setMinimum(minimum);
    }
    
    @Override
    public int getMaximum() {
        return this.getModel().getMaximum();
    }
    
    @Override
    public void setMaximum(int maximum) {
        this.getModel().setMaximum(maximum);
    }
    
    public boolean getValueIsAdjusting() {
        return this.getModel().getValueIsAdjusting();
    }
    
    public void setValueIsAdjusting(boolean valueIsAdjusting) {
        BoundedRangeModel model = this.getModel();
        int valueIsAdjusting2 = model.getValueIsAdjusting();
        model.setValueIsAdjusting(valueIsAdjusting);
        if (valueIsAdjusting2 != (valueIsAdjusting ? 1 : 0) && this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleState", valueIsAdjusting2 ? AccessibleState.BUSY : null, valueIsAdjusting ? AccessibleState.BUSY : null);
        }
    }
    
    public void setValues(int n, int n2, int n3, int n4) {
        BoundedRangeModel model = this.getModel();
        int value = model.getValue();
        model.setRangeProperties(n, n2, n3, n4, model.getValueIsAdjusting());
        if (this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleValue", Integer.valueOf(value), Integer.valueOf(model.getValue()));
        }
    }
    
    @Override
    public void addAdjustmentListener(AdjustmentListener l) {
        this.listenerList.add(AdjustmentListener.class, l);
    }
    
    @Override
    public void removeAdjustmentListener(AdjustmentListener l) {
        this.listenerList.remove(AdjustmentListener.class, l);
    }
    
    public AdjustmentListener[] getAdjustmentListeners() {
        return (AdjustmentListener[])this.listenerList.getListeners(AdjustmentListener.class);
    }
    
    protected void fireAdjustmentValueChanged(int n, int n2, int n3) {
        this.fireAdjustmentValueChanged(n, n2, n3, this.getValueIsAdjusting());
    }
    
    private void fireAdjustmentValueChanged(int id, int type, int value, boolean isAdjusting) {
        Object[] listenerList = this.listenerList.getListenerList();
        Object o = null;
        for (int i = listenerList.length - 2; i >= 0; i -= 2) {
            if (listenerList[i] == AdjustmentListener.class) {
                if (o == null) {
                    o = new AdjustmentEvent(this, id, type, value, isAdjusting);
                }
                ((AdjustmentListener)listenerList[i + 1]).adjustmentValueChanged(o);
            }
        }
    }
    
    @Override
    public Dimension getMinimumSize() {
        Dimension preferredSize = this.getPreferredSize();
        if (this.orientation == 1) {
            return new Dimension(preferredSize.width, 5);
        }
        return new Dimension(5, preferredSize.height);
    }
    
    @Override
    public Dimension getMaximumSize() {
        Dimension preferredSize = this.getPreferredSize();
        if (this.getOrientation() == 1) {
            return new Dimension(preferredSize.width, 32767);
        }
        return new Dimension(32767, preferredSize.height);
    }
    
    @Override
    public void setEnabled(boolean b) {
        super.setEnabled(b);
        Component[] components = this.getComponents();
        for (int length = components.length, i = 0; i < length; ++i) {
            components[i].setEnabled(b);
        }
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("ScrollBarUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                this.ui.installUI(this);
            }
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString() + ",blockIncrement=" + this.blockIncrement + ",orientation=" + ((this.orientation == 0) ? "HORIZONTAL" : "VERTICAL") + ",unitIncrement=" + this.unitIncrement;
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JScrollBar.AccessibleJScrollBar();
        }
        return this.accessibleContext;
    }
    
    static void access$100(JScrollBar scrollBar, int n, int n2, int n3, boolean b) {
        scrollBar.fireAdjustmentValueChanged(n, n2, n3, b);
    }
    
    private class ModelListener implements ChangeListener, Serializable
    {
        @Override
        public void stateChanged(ChangeEvent changeEvent) {
            Object source = changeEvent.getSource();
            if ((source instanceof BoundedRangeModel)) {
                int n = 601;
                int n2 = 5;
                BoundedRangeModel boundedRangeModel = (BoundedRangeModel)source;
                JScrollBar.access$100(JScrollBar.this, n, n2, boundedRangeModel.getValue(), boundedRangeModel.getValueIsAdjusting());
            }
        }
    }
    
    protected class AccessibleJScrollBar extends JComponent.AccessibleJComponent implements AccessibleValue
    {
        @Override
        public AccessibleStateSet getAccessibleStateSet() {
            AccessibleStateSet accessibleStateSet = super.getAccessibleStateSet();
            if (JScrollBar.this.getValueIsAdjusting()) {
                accessibleStateSet.add(AccessibleState.BUSY);
            }
            if (JScrollBar.this.getOrientation() == 1) {
                accessibleStateSet.add(AccessibleState.VERTICAL);
                return accessibleStateSet;
            }
            accessibleStateSet.add(AccessibleState.HORIZONTAL);
            return accessibleStateSet;
        }
        
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.SCROLL_BAR;
        }
        
        @Override
        public AccessibleValue getAccessibleValue() {
            return this;
        }
        
        @Override
        public Number getCurrentAccessibleValue() {
            return Integer.valueOf(JScrollBar.this.getValue());
        }
        
        @Override
        public boolean setCurrentAccessibleValue(Number n) {
            if (n == null) {
                return false;
            }
            JScrollBar.this.setValue(n.intValue());
            return true;
        }
        
        @Override
        public Number getMinimumAccessibleValue() {
            return Integer.valueOf(JScrollBar.this.getMinimum());
        }
        
        @Override
        public Number getMaximumAccessibleValue() {
            return new Integer(JScrollBar.this.model.getMaximum() - JScrollBar.this.model.getExtent());
        }
    }
}
